==> copyq-2.4.2.tar.gz: CopyQ-2.4.2/src/platform/platformclipboard.h <==
/*
    Copyright (c) 2014, Lukas Holecek <hluk@email.cz>

    This file is part of CopyQ.

    CopyQ is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CopyQ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLATFORMCLIPBOARD_H
#define PLATFORMCLIPBOARD_H

#include <QObject>
#include <QVariantMap>

/**
 * Interface for clipboard.
 *
 * Define signal changed(PlatformClipboard::Mode) in derived class.
 * This signal notifies about clipboard changes.
 */
class PlatformClipboard : public QObject
{
public:
    enum Mode {
        Clipboard,
        Selection,
        FindBuffer
    };

    /**
     * Load settings from GUI.
     *
     * Settings keys are:
     *   - "copy_clipboard" (bool)  - copy new clipboard data to X11 selection
     *   - "copy_selection" (bool)  - copy new X11 selection data to clipboard
     *   - "check_selection" (bool) - emit changed() when X11 selection changes
     *   - "formats" (QStringList)  - string list with MIME formats to store
     *     (formats are also passed to data() method call from ClipboardMonitor)
     */
    virtual void loadSettings(const QVariantMap &settings) = 0;

    /**
     * Return clipboard data containing specified @a formats if available.
     */
    virtual QVariantMap data(Mode mode, const QStringList &formats) const = 0;

    /**
     * Set data to clipboard.
     */
    virtual void setData(Mode mode, const QVariantMap &dataMap) = 0;

    /**
     * Triggered by "ignore()" script command.
     *
     * Some applications reset clipboard so that passwords and sensitive data are kept
     * in clipboard only while really needed.
     *
     * On X11 clipboard/selection synchronization should be canceled and previously
     * synchronized content should be cleared.
     */
    virtual void ignoreCurrentData() = 0;
};

#endif // PLATFORMCLIPBOARD_H

==> copyq_3.7.1.orig.tar.gz: CopyQ-3.7.1/src/platform/platformclipboard.h <==
/*
    Copyright (c) 2018, Lukas Holecek <hluk@email.cz>

    This file is part of CopyQ.

    CopyQ is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    CopyQ is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLATFORMCLIPBOARD_H
#define PLATFORMCLIPBOARD_H

#include "common/clipboardmode.h"

#include <QObject>
#include <QVariantMap>

/**
 * Interface for clipboard.
 */
class PlatformClipboard : public QObject
{
    Q_OBJECT
public:
    /**
     * Set MIME types to monitor.
     */
    virtual void setFormats(const QStringList &formats) = 0;

    /**
     * Return clipboard data containing specified @a formats if available.
     */
    virtual QVariantMap data(ClipboardMode mode, const QStringList &formats) const = 0;

    /**
     * Set data to clipboard.
     */
    virtual void setData(ClipboardMode mode, const QVariantMap &dataMap) = 0;

signals:
    /// Notifies about clipboard changes.
    void changed(ClipboardMode mode);
};

#endif // PLATFORMCLIPBOARD_H
